@@ -98,8 +98,8 @@ is_supported_extension (GtkWidget *file_sel,
 			char      *filename)
 {
 	int i;
-	for (i = 0; save_type[i] != FR_FILE_TYPE_NULL; i++)
-		if (file_extension_is (filename, file_type_desc[save_type[i]].ext))
+	for (i = 0; save_type[i] != -1; i++)
+		if (file_extension_is (filename, mime_type_desc[save_type[i]].default_ext))
 			return TRUE;
 	return FALSE;
 }
@@ -126,8 +126,11 @@ get_full_path (SaveAsData *data)
 
 	idx = gtk_combo_box_get_active (GTK_COMBO_BOX (data->combo_box));
 	if (idx > 0) {
-		const char *path_ext = fr_archive_utils__get_file_name_ext (path);
-		char       *default_ext = file_type_desc[save_type[idx-1]].ext;
+		const char *path_ext;
+		char       *default_ext;
+		
+		path_ext = get_archive_filename_extension (path);
+		default_ext = mime_type_desc[save_type[idx-1]].default_ext;
 		if (strcmp_null_tolerant (path_ext, default_ext) != 0) {
 			full_path = g_strconcat (path, default_ext, NULL);
 			g_free (path);
@@ -206,14 +209,14 @@ get_archive_filename_from_selector (SaveAsData *data)
 
 	/* if the user did not specify a valid extension use the filetype combobox current type
 	 * or tar.gz if automatic is selected. */
-	if (fr_archive_utils__get_file_name_ext (path) == NULL) {
+	if (get_archive_filename_extension (path) == NULL) {
 		int   idx;
 		char *new_path;
 		char *ext = NULL;
 
 		idx = gtk_combo_box_get_active (GTK_COMBO_BOX (data->combo_box));
 		if (idx > 0)
-			ext = file_type_desc[save_type[idx-1]].ext;
+			ext = mime_type_desc[save_type[idx-1]].default_ext;
 		else
 			ext = ".tar.gz";
 		new_path = g_strconcat (path, ext, NULL);
@@ -306,10 +309,10 @@ update_password_availability_for_ext (SaveAsData *data,
 		return;
 	}
 				
-	for (i = 0; file_type_desc[i].id != FR_FILE_TYPE_NULL; i++) {
-		if (strcmp (file_type_desc[i].ext, ext) == 0) {
-			gtk_widget_set_sensitive (data->password, file_type_desc[i].supports_password);
-			gtk_widget_set_sensitive (data->password_label, file_type_desc[i].supports_password);
+	for (i = 0; mime_type_desc[i].mime_type != NULL; i++) {
+		if (strcmp (mime_type_desc[i].default_ext, ext) == 0) {
+			gtk_widget_set_sensitive (data->password, mime_type_desc[i].supports_password);
+			gtk_widget_set_sensitive (data->password_label, mime_type_desc[i].supports_password);
 			break;
 		}
 	}
@@ -331,7 +334,7 @@ filetype_combobox_changed_cb (GtkComboBox *combo_box,
 	if (uri == NULL)
 		return;
 	
-	ext = fr_archive_utils__get_file_name_ext (uri);
+	ext = get_archive_filename_extension (uri);
 	if (ext == NULL)
 		ext = "";
 	
@@ -347,7 +350,7 @@ filetype_combobox_changed_cb (GtkComboBox *combo_box,
 	basename = file_name_from_path (uri);
 	basename_noext = g_strndup (basename, strlen (basename) - strlen (ext));
 
-	new_ext = file_type_desc[save_type[idx]].ext;
+	new_ext = mime_type_desc[save_type[idx]].default_ext;
 	new_basename = g_strconcat (basename_noext, new_ext, NULL);
 	new_basename_uft8 = g_uri_unescape_string (new_basename, NULL);
 	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (data->file_sel), new_basename_uft8);
@@ -397,8 +400,8 @@ show_new_archive_dialog (FrWindow   *window,
 
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("All archives"));
-	for (i = 0; save_type[i] != FR_FILE_TYPE_NULL; i++)
-		gtk_file_filter_add_mime_type (filter, file_type_desc[save_type[i]].mime_type);
+	for (i = 0; save_type[i] != -1; i++)
+		gtk_file_filter_add_mime_type (filter, mime_type_desc[save_type[i]].mime_type);
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (file_sel), filter);
 
@@ -418,9 +421,9 @@ show_new_archive_dialog (FrWindow   *window,
 
 	data->combo_box = gtk_combo_box_new_text ();
 	gtk_combo_box_append_text (GTK_COMBO_BOX (data->combo_box), _("Automatic"));
-	for (i = 0; save_type[i] != FR_FILE_TYPE_NULL; i++)
+	for (i = 0; save_type[i] != -1; i++)
 		gtk_combo_box_append_text (GTK_COMBO_BOX (data->combo_box),
-					   _(file_type_desc[save_type[i]].name));
+					   _(mime_type_desc[save_type[i]].name));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (data->combo_box), 0);
 	gtk_box_pack_start (GTK_BOX (hbox), data->combo_box, TRUE, TRUE, 0);
 	gtk_widget_show_all (hbox);
@@ -523,8 +526,8 @@ activate_action_open (GtkAction *action,
 
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("All archives"));
-	for (i = 0; open_type[i] != FR_FILE_TYPE_NULL; i++)
-		gtk_file_filter_add_mime_type (filter, file_type_desc[open_type[i]].mime_type);
+	for (i = 0; open_type[i] != -1; i++)
+		gtk_file_filter_add_mime_type (filter, mime_type_desc[open_type[i]].mime_type);
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (file_sel), filter);
 
@@ -644,8 +647,8 @@ activate_action_save_as (GtkAction *action,
 
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("All archives"));
-	for (i = 0; save_type[i] != FR_FILE_TYPE_NULL; i++)
-		gtk_file_filter_add_mime_type (filter, file_type_desc[save_type[i]].mime_type);
+	for (i = 0; save_type[i] != -1; i++)
+		gtk_file_filter_add_mime_type (filter, mime_type_desc[save_type[i]].mime_type);
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (file_sel), filter);
 
@@ -673,9 +676,9 @@ activate_action_save_as (GtkAction *action,
 
 	data->combo_box = gtk_combo_box_new_text ();
 	gtk_combo_box_append_text (GTK_COMBO_BOX (data->combo_box), _("Automatic"));
-	for (i = 0; save_type[i] != FR_FILE_TYPE_NULL; i++)
+	for (i = 0; save_type[i] != -1; i++)
 		gtk_combo_box_append_text (GTK_COMBO_BOX (data->combo_box),
-					   _(file_type_desc[save_type[i]].name));
+					   _(mime_type_desc[save_type[i]].name));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (data->combo_box), 0);
 	gtk_table_attach (GTK_TABLE (table), data->combo_box, 1, 2, 0, 1,
 			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
