@@ -25,13 +25,12 @@
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include "glib-utils.h"
 #include "file-utils.h"
 #include "gtk-utils.h"
-#include "window.h"
+#include "fr-window.h"
 
-#define PROP_GLADE_FILE "file-roller.glade"
+#define GLADE_FILE "properties.glade"
 
 
 typedef struct {
@@ -43,10 +42,10 @@ typedef struct {
 /* called when the main dialog is closed. */
 static void
 destroy_cb (GtkWidget  *widget,
-            DialogData *data)
+	    DialogData *data)
 {
 	g_object_unref (G_OBJECT (data->gui));
-        g_free (data);
+	g_free (data);
 }
 
 
@@ -78,41 +77,40 @@ help_cb (GtkWidget   *w,
 
 
 void
-dlg_prop (FRWindow *window)
+dlg_prop (FrWindow *window)
 {
-        DialogData       *data;
+	DialogData       *data;
 	GtkWidget        *ok_button;
 	GtkWidget        *help_button;
 	GtkWidget        *label_label;
 	GtkWidget        *label;
 	char             *s;
-	GnomeVFSFileSize  size, uncompressed_size;
+	goffset           size, uncompressed_size;
 	char             *utf8_name;
 	char             *title_txt;
 	double            ratio;
 
-        data = g_new (DialogData, 1);
+	data = g_new (DialogData, 1);
 
-	data->gui = glade_xml_new (GLADEDIR "/" PROP_GLADE_FILE , NULL, NULL);
+	data->gui = glade_xml_new (GLADEDIR "/" GLADE_FILE , NULL, NULL);
 	if (!data->gui) {
-                g_warning ("Could not find " PROP_GLADE_FILE "\n");
-                return;
-        }
+		g_warning ("Could not find " GLADE_FILE "\n");
+		return;
+	}
 
-        /* Get the widgets. */
+	/* Get the widgets. */
 
-        data->dialog = glade_xml_get_widget (data->gui, "prop_dialog");
+	data->dialog = glade_xml_get_widget (data->gui, "prop_dialog");
 	ok_button = glade_xml_get_widget (data->gui, "p_ok_button");
 	help_button = glade_xml_get_widget (data->gui, "p_help_button");
 
 	/* Set widgets data. */
 
 	label_label = glade_xml_get_widget (data->gui, "p_path_label_label");
-	set_label (label_label, _("Path:"));
+	set_label (label_label, _("Location:"));
 
 	label = glade_xml_get_widget (data->gui, "p_path_label");
-	/* note: window->archive_filename is unescaped. */
-	s = remove_level_from_path (window->archive_filename);
+	s = remove_level_from_path (fr_window_get_archive_uri (window));
 	utf8_name = g_filename_display_name (s);
 	gtk_label_set_text (GTK_LABEL (label), utf8_name);
 	g_free (utf8_name);
@@ -124,7 +122,7 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Name:"));
 
 	label = glade_xml_get_widget (data->gui, "p_name_label");
-	utf8_name = g_filename_display_basename (window->archive_filename);
+	utf8_name = g_filename_display_basename (fr_window_get_archive_uri (window));
 	gtk_label_set_text (GTK_LABEL (label), utf8_name);
 
 	title_txt = g_strdup_printf (_("%s Properties"), utf8_name);
@@ -139,7 +137,7 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Modified on:"));
 
 	label = glade_xml_get_widget (data->gui, "p_date_label");
-	s = get_time_string (get_file_mtime (window->archive->filename));
+	s = get_time_string (get_file_mtime (fr_window_get_archive_uri (window)));
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
@@ -149,8 +147,8 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Archive size:"));
 
 	label = glade_xml_get_widget (data->gui, "p_size_label");
-	size = get_file_size (window->archive_filename);
-	s = gnome_vfs_format_file_size_for_display (size);
+	size = get_file_size (fr_window_get_archive_uri (window));
+	s = g_format_size_for_display (size);
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
@@ -160,16 +158,17 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Content size:"));
 
 	uncompressed_size = 0;
-	if (window->archive_present) {
-		GList *scan = window->archive->command->file_list;
-		for (; scan; scan = scan->next) {
-			FileData *fd = scan->data;
+	if (fr_window_archive_is_present (window)) {
+		int i;
+		
+		for (i = 0; i < window->archive->command->files->len; i++) {
+			FileData *fd = g_ptr_array_index (window->archive->command->files, i);
 			uncompressed_size += fd->size;
 		}
 	}
 
 	label = glade_xml_get_widget (data->gui, "p_uncomp_size_label");
-	s = gnome_vfs_format_file_size_for_display (uncompressed_size);
+	s = g_format_size_for_display (uncompressed_size);
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
@@ -194,7 +193,7 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Number of files:"));
 
 	label = glade_xml_get_widget (data->gui, "p_files_label");
-	s = g_strdup_printf ("%d", g_list_length (window->archive->command->file_list));
+	s = g_strdup_printf ("%d", window->archive->command->files->len);
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
@@ -211,13 +210,13 @@ dlg_prop (FRWindow *window)
 	g_signal_connect (G_OBJECT (help_button),
 			  "clicked",
 			  G_CALLBACK (help_cb),
-			  G_OBJECT (data));
+			  data);
 
 	/* Run dialog. */
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
-				      GTK_WINDOW (window->app));
-        gtk_window_set_modal         (GTK_WINDOW (data->dialog), TRUE);
+				      GTK_WINDOW (window));
+	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE);
 
 	gtk_widget_show (data->dialog);
 }
