@@ -253,7 +253,7 @@ get_dir_content_if_unique (const char  *uri)
 			break;
 		}
 		
-		content_uri = g_build_path (uri, name, NULL);
+		content_uri = build_uri (uri, name, NULL);
 		g_object_unref (info);
 	}
 	
@@ -366,6 +366,20 @@ get_file_mtime (const char *uri)
 }
 
 
+time_t
+get_file_mtime_for_path (const char *path)
+{
+	char   *uri;
+	time_t  result;
+	
+	uri = g_filename_to_uri (path, NULL, NULL);
+	result = get_file_mtime (uri);
+	g_free (uri);
+	
+	return result;
+}
+
+
 time_t
 get_file_ctime (const char *uri)
 {
@@ -459,6 +473,43 @@ remove_level_from_path (const gchar *path)
 }
 
 
+char *
+remove_ending_separator (const char *path)
+{
+	gint len, copy_len;
+
+	if (path == NULL)
+		return NULL;
+
+	copy_len = len = strlen (path);
+	if ((len > 1) && (path[len - 1] == '/'))
+		copy_len--;
+
+	return g_strndup (path, copy_len);
+}
+
+
+char *
+build_uri (const char *base, ...)
+{
+	va_list     args;
+	const char *child;
+	GString    *uri;
+	
+	uri = g_string_new (base);
+	
+	va_start (args, base);
+        while ((child = va_arg (args, const char *)) != NULL) {
+        	if (! g_str_has_suffix (uri->str, "/") && ! g_str_has_prefix (child, "/"))
+        		g_string_append (uri, "/");
+        	g_string_append (uri, child);
+        }
+	va_end (args);
+	
+	return g_string_free (uri, FALSE);
+}
+
+
 gchar *
 remove_extension_from_path (const gchar *path)
 {
@@ -485,22 +536,6 @@ remove_extension_from_path (const gchar *path)
 }
 
 
-char *
-remove_ending_separator (const char *path)
-{
-	gint len, copy_len;
-
-	if (path == NULL)
-		return NULL;
-
-	copy_len = len = strlen (path);
-	if ((len > 1) && (path[len - 1] == '/'))
-		copy_len--;
-
-	return g_strndup (path, copy_len);
-}
-
-
 gboolean
 make_directory_tree (GFile    *dir,
 		     mode_t    mode,
@@ -580,6 +615,37 @@ make_directory_tree_from_path (const char  *path,
 }
 
 
+const char *
+get_file_extension (const char *filename)
+{
+	const char *ptr = filename;
+	int         len;
+	int         p;
+	const char *ext;
+	
+	if (filename == NULL)
+		return NULL;
+
+	len = strlen (filename);
+	if (len <= 1)
+		return NULL;
+
+	p = len - 1;
+	while ((p >= 0) && (ptr[p] != '.'))
+		p--;
+	if (p < 0)
+		return NULL;
+
+	ext = filename + p;	
+	if (ext - 4 > filename) {
+		const char *test = ext - 4;
+		if (strncmp (test, ".tar", 4) == 0)
+			ext = ext - 4;
+	} 
+	return ext;
+}
+
+
 gboolean
 file_extension_is (const char *filename,
 		   const char *ext)
@@ -715,7 +781,7 @@ delete_directory_recursive (GFile   *dir,
 		char  *child_uri;
 		GFile *child;
 		
-		child_uri = g_build_path ("/", uri, g_file_info_get_name (info), NULL);
+		child_uri = build_uri (uri, g_file_info_get_name (info), NULL);
 		child = g_file_new_for_uri (child_uri);
 		
 		switch (g_file_info_get_file_type (info)) {
@@ -821,6 +887,9 @@ get_temp_work_dir (void)
 			g_free (folder);
 	}
 
+	if ((best_folder == NULL) || (strncmp (best_folder, "file://", 7) != 0))
+		return NULL;
+
 	template = g_strconcat (best_folder + strlen ("file://"), "/.fr-XXXXXX", NULL);
 	result = mkdtemp (template);
 
