@@ -229,7 +229,7 @@ fr_command_7z_add (FrCommand     *comm,
 		   const char    *base_dir,
 		   gboolean       update,
 		   const char    *password,
-		   FRCompression  compression)
+		   FrCompression  compression)
 {
 	GList *scan;
 
@@ -354,7 +354,7 @@ fr_command_7z_test (FrCommand   *comm,
 
 static void
 fr_command_7z_handle_error (FrCommand   *comm,
-			    FRProcError *error)
+			    FrProcError *error)
 {
 	if (error->type == FR_PROC_ERROR_COMMAND_ERROR) {
 		if (error->status <= 1)
@@ -363,6 +363,22 @@ fr_command_7z_handle_error (FrCommand   *comm,
 }
 
 
+static void
+fr_command_7z_set_mime_type (FrCommand  *comm,
+			     const char *mime_type)
+{
+	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
+	
+	comm->capabilities |= FR_COMMAND_CAP_ARCHIVE_MANY_FILES;
+	if (is_program_in_path ("7za")) 
+		comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
+	else if (is_program_in_path ("7zr")) 
+		comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
+	else if (is_program_in_path ("7z")) 
+		comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
+}
+
+
 static void
 fr_command_7z_class_init (FrCommand7zClass *class)
 {
@@ -380,14 +396,13 @@ fr_command_7z_class_init (FrCommand7zClass *class)
 	afc->extract        = fr_command_7z_extract;
 	afc->test           = fr_command_7z_test;
 	afc->handle_error   = fr_command_7z_handle_error;
+	afc->set_mime_type  = fr_command_7z_set_mime_type;
 }
 
 
 static void
 fr_command_7z_init (FrCommand *comm)
 {
-	comm->file_type = FR_FILE_TYPE_7ZIP;
-
 	comm->propAddCanUpdate             = TRUE;
 	comm->propAddCanReplace            = TRUE;
 	comm->propAddCanStoreFolders       = TRUE;
@@ -437,22 +452,3 @@ fr_command_7z_get_type ()
 
 	return type;
 }
-
-
-FrCommand *
-fr_command_7z_new (FrProcess  *process,
-		   const char *filename)
-{
-	FrCommand *comm;
-
-	if (! is_program_in_path("7za")
-	    && ! is_program_in_path("7zr")
-	    && ! is_program_in_path("7z")) { 
-		return NULL;
-	}
-
-	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_7Z, NULL));
-	fr_command_construct (comm, process, filename);
-
-	return comm;
-}
