@@ -209,7 +209,7 @@ fr_command_ar_add (FrCommand     *comm,
 		   const char    *base_dir,
 		   gboolean       update,
 		   const char    *password,
-		   FRCompression  compression)
+		   FrCompression  compression)
 {
 	GList *scan;
 
@@ -277,12 +277,24 @@ fr_command_ar_extract (FrCommand  *comm,
 
 static void
 fr_command_ar_handle_error (FrCommand   *comm, 
-			    FRProcError *error)
+			    FrProcError *error)
 {
 	/* FIXME */
 }
 
 
+static void
+fr_command_ar_set_mime_type (FrCommand  *comm,
+			     const char *mime_type)
+{
+	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
+	
+	comm->capabilities |= FR_COMMAND_CAP_ARCHIVE_MANY_FILES;
+	if (is_program_in_path ("ar")) 
+		comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
+}
+
+
 static void 
 fr_command_ar_class_init (FrCommandArClass *class)
 {
@@ -299,14 +311,13 @@ fr_command_ar_class_init (FrCommandArClass *class)
 	afc->delete         = fr_command_ar_delete;
 	afc->extract        = fr_command_ar_extract;
 	afc->handle_error   = fr_command_ar_handle_error;
+	afc->set_mime_type  = fr_command_ar_set_mime_type;
 }
 
  
 static void 
 fr_command_ar_init (FrCommand *comm)
 {
-	comm->file_type = FR_FILE_TYPE_AR;
-
 	comm->propCanModify                = TRUE;
 	comm->propAddCanUpdate             = TRUE;
 	comm->propAddCanReplace            = TRUE;
@@ -357,19 +368,3 @@ fr_command_ar_get_type ()
 
         return type;
 }
-
-
-FrCommand *
-fr_command_ar_new (FrProcess  *process,
-		   const char *filename)
-{
-	FrCommand *comm;
-
-	if(! is_program_in_path ("ar")) 
-		return NULL;
-	
-	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_AR, NULL));
-	fr_command_construct (comm, process, filename);
-	
-	return comm;
-}
