@@ -107,14 +107,12 @@ list__process_line (char     *line,
 		return;
 	}
 
-	if (arj_comm->line_no == 4) {
-		arj_comm->line_no = 1;
-		return;
-
-	} else if (arj_comm->line_no == 1) { /* Read the filename. */
+	if (line[0] != ' ') { /* Read the filename. */
 		FileData   *fdata;
 		const char *name_field;
 
+		arj_comm->line_no = 1;
+
 		arj_comm->fdata = fdata = file_data_new ();
 
 		name_field = get_last_field (line, 2);
@@ -122,7 +120,8 @@ list__process_line (char     *line,
 		if (*name_field == '/') {
 			fdata->full_path = g_strdup (name_field);
 			fdata->original_path = fdata->full_path;
-		} else {
+		} 
+		else {
 			fdata->full_path = g_strconcat ("/", name_field, NULL);
 			fdata->original_path = fdata->full_path + 1;
 		}
@@ -131,8 +130,8 @@ list__process_line (char     *line,
 
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-
-	} else if (arj_comm->line_no == 2) { /* Read file size and date. */
+	} 
+	else if (arj_comm->line_no == 2) { /* Read file size and date. */
 		FileData  *fdata;
 		char     **fields;
 
@@ -143,7 +142,10 @@ list__process_line (char     *line,
 		fields = split_line (line, 10);
 		fdata->size = g_ascii_strtoull (fields[2], NULL, 10);
 		fdata->modified = mktime_from_string (fields[5], fields[6]);
-		fdata->encrypted = (g_ascii_strcasecmp (fields[9], "11") == 0);
+		if (strcmp (fields[1], "MS-DOS") == 0)
+			fdata->encrypted = (g_ascii_strcasecmp (fields[7], "11") == 0);
+		else
+			fdata->encrypted = (g_ascii_strcasecmp (fields[9], "11") == 0);			
 		g_strfreev (fields);
 
 		if (*fdata->name == 0)
@@ -152,7 +154,7 @@ list__process_line (char     *line,
 			fr_command_add_file (comm, fdata);
 		arj_comm->fdata = NULL;
 	}
-
+		
 	arj_comm->line_no++;
 }
 
@@ -181,7 +183,7 @@ fr_command_arj_add (FrCommand     *comm,
 		    const char    *base_dir,
 		    gboolean       update,
 		    const char    *password,
-		    FRCompression  compression)
+		    FrCompression  compression)
 {
 	GList *scan;
 
@@ -319,7 +321,7 @@ fr_command_arj_test (FrCommand   *comm,
 
 static void
 fr_command_arj_handle_error (FrCommand   *comm,
-			     FRProcError *error)
+			     FrProcError *error)
 {
 	if (error->type == FR_PROC_ERROR_COMMAND_ERROR) {
  		if (error->status <= 1)
@@ -330,6 +332,18 @@ fr_command_arj_handle_error (FrCommand   *comm,
 }
 
 
+static void
+fr_command_arj_set_mime_type (FrCommand  *comm,
+		 	      const char *mime_type)
+{
+	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
+	
+	comm->capabilities |= FR_COMMAND_CAP_ARCHIVE_MANY_FILES;
+	if (is_program_in_path ("arj")) 
+		comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
+}
+
+
 static void
 fr_command_arj_class_init (FrCommandArjClass *class)
 {
@@ -347,14 +361,13 @@ fr_command_arj_class_init (FrCommandArjClass *class)
 	afc->extract        = fr_command_arj_extract;
 	afc->test           = fr_command_arj_test;
 	afc->handle_error   = fr_command_arj_handle_error;
+	afc->set_mime_type  = fr_command_arj_set_mime_type;
 }
 
 
 static void
 fr_command_arj_init (FrCommand *comm)
 {
-	comm->file_type = FR_FILE_TYPE_ARJ;
-
 	comm->propAddCanUpdate             = TRUE;
 	comm->propAddCanReplace            = TRUE;
 	comm->propAddCanStoreFolders       = FALSE;
@@ -407,20 +420,3 @@ fr_command_arj_get_type ()
 
 	return type;
 }
-
-
-FrCommand *
-fr_command_arj_new (FrProcess  *process,
-		    const char *filename)
-{
-	FrCommand *comm;
-
-	if (!is_program_in_path("arj")) {
-		return NULL;
-	}
-
-	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_ARJ, NULL));
-	fr_command_construct (comm, process, filename);
-
-	return comm;
-}
