@@ -31,6 +31,9 @@
 #include "fr-command.h"
 #include "fr-marshal.h"
 
+#define INITIAL_SIZE 256
+
+/* Signals */
 enum {
 	START,
 	DONE,
@@ -39,6 +42,14 @@ enum {
 	LAST_SIGNAL
 };
 
+/* Properties */
+enum {
+        PROP_0,
+        PROP_FILENAME,
+        PROP_MIME_TYPE,
+        PROP_PROCESS
+};
+
 static GObjectClass *parent_class = NULL;
 static guint fr_command_signals[LAST_SIGNAL] = { 0 };
 
@@ -101,7 +112,7 @@ base_fr_command_add (FrCommand     *comm,
 		     const char    *base_dir,
 		     gboolean       update,
 		     const char    *password,
-		     FRCompression  compression)
+		     FrCompression  compression)
 {
 }
 
@@ -140,7 +151,7 @@ base_fr_command_uncompress (FrCommand *comm)
 
 static void
 base_fr_command_recompress (FrCommand     *comm,
-			    FRCompression  compression)
+			    FrCompression  compression)
 {
 }
 
@@ -155,18 +166,169 @@ base_fr_command_escape (FrCommand     *comm,
 
 static void
 base_fr_command_handle_error (FrCommand *comm,
-			      FRProcError *error)
+			      FrProcError *error)
 {
 }
 
 
+static void
+base_fr_command_set_mime_type (FrCommand  *comm,
+			       const char *mime_type)
+{
+	comm->mime_type = get_static_string (mime_type);
+}
+
+
+static void
+fr_command_start (FrProcess *process,
+		  gpointer   data)
+{
+	FrCommand *comm = FR_COMMAND (data);
+	
+	g_signal_emit (G_OBJECT (comm),
+		       fr_command_signals[START], 
+		       0,
+		       comm->action);
+}
+
+
+static void
+fr_command_done (FrProcess   *process,
+		 gpointer     data)
+{
+	FrCommand *comm = FR_COMMAND (data);
+
+	comm->process->restart = FALSE;
+	if (process->error.type != FR_PROC_ERROR_NONE)
+		fr_command_handle_error (comm, &process->error);
+
+	if (comm->process->restart)
+		fr_process_start (comm->process);
+	else
+		g_signal_emit (G_OBJECT (comm),
+			       fr_command_signals[DONE], 
+			       0,
+			       comm->action, 
+			       &process->error);
+}
+
+
+static void
+fr_command_set_process (FrCommand  *comm,
+		        FrProcess  *process)
+{
+	if (comm->process != NULL) {
+		g_signal_handlers_disconnect_matched (G_OBJECT (comm->process),
+					      G_SIGNAL_MATCH_DATA, 
+					      0, 
+					      0, NULL, 
+					      0,
+					      comm);
+		g_object_unref (G_OBJECT (comm->process));
+		comm->process = NULL;
+	}
+	
+	if (process == NULL)
+		return;
+	
+	g_object_ref (G_OBJECT (process));
+	comm->process = process;
+	g_signal_connect (G_OBJECT (comm->process),
+			  "start",
+			  G_CALLBACK (fr_command_start),
+			  comm);
+	g_signal_connect (G_OBJECT (comm->process),
+			  "done",
+			  G_CALLBACK (fr_command_done),
+			  comm);
+}
+
+
+static void
+fr_command_set_property (GObject      *object,
+			 guint         prop_id,
+			 const GValue *value,
+			 GParamSpec   *pspec)
+{
+        FrCommand *comm;
+
+        comm = FR_COMMAND (object);
+
+        switch (prop_id) {
+        case PROP_PROCESS:
+                fr_command_set_process (comm, g_value_get_object (value));
+                break;
+        case PROP_FILENAME:
+        	fr_command_set_filename (comm, g_value_get_string (value));
+                break;
+        case PROP_MIME_TYPE:
+        	fr_command_set_mime_type (comm, g_value_get_string (value));
+                break;
+        default:
+                break;
+        }
+}
+
+
+static void
+fr_command_get_property (GObject    *object,
+			 guint       prop_id,
+			 GValue     *value,
+			 GParamSpec *pspec)
+{
+        FrCommand *comm;
+
+        comm = FR_COMMAND (object);
+
+        switch (prop_id) {
+        case PROP_PROCESS:
+                g_value_set_object (value, comm->process);
+                break;
+        case PROP_FILENAME:
+        	g_value_set_string (value, comm->filename);
+                break;
+        case PROP_MIME_TYPE:
+                g_value_set_static_string (value, comm->mime_type);
+                break;
+        default:
+                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+                break;
+        }
+}
+
+
 static void
 fr_command_class_init (FrCommandClass *class)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+	GObjectClass *gobject_class;
 
 	parent_class = g_type_class_peek_parent (class);
 
+	gobject_class = G_OBJECT_CLASS (class);
+	
+	/* virtual functions */
+	
+	gobject_class->finalize = fr_command_finalize;
+	gobject_class->set_property = fr_command_set_property;
+        gobject_class->get_property = fr_command_get_property;
+               
+	class->list           = base_fr_command_list;
+	class->add            = base_fr_command_add;
+	class->delete         = base_fr_command_delete;
+	class->extract        = base_fr_command_extract;
+	class->test           = base_fr_command_test;
+	class->uncompress     = base_fr_command_uncompress;
+	class->recompress     = base_fr_command_recompress;
+	class->escape         = base_fr_command_escape;
+	class->handle_error   = base_fr_command_handle_error;
+	class->set_mime_type  = base_fr_command_set_mime_type;
+	class->start          = NULL;
+	class->done           = NULL;
+	class->progress       = NULL;
+	class->message        = NULL;
+	
+	/* signals */
+	
 	fr_command_signals[START] =
 		g_signal_new ("start",
 			      G_TYPE_FROM_CLASS (class),
@@ -204,34 +366,40 @@ fr_command_class_init (FrCommandClass *class)
 			      fr_marshal_VOID__STRING,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
-
-	gobject_class->finalize = fr_command_finalize;
-
-	class->list           = base_fr_command_list;
-	class->add            = base_fr_command_add;
-	class->delete         = base_fr_command_delete;
-	class->extract        = base_fr_command_extract;
-	class->test           = base_fr_command_test;
-
-	class->uncompress     = base_fr_command_uncompress;
-	class->recompress     = base_fr_command_recompress;
-
-	class->escape         = base_fr_command_escape;
-	class->handle_error   = base_fr_command_handle_error;
-
-	class->start          = NULL;
-	class->done           = NULL;
-	class->progress       = NULL;
-	class->message        = NULL;
+			      
+	/* properties */
+	
+	g_object_class_install_property (gobject_class,
+					 PROP_PROCESS,
+					 g_param_spec_object ("process",
+							      "Processs",
+							      "The process object used by the command",
+							      FR_TYPE_PROCESS,
+							      G_PARAM_READWRITE));
+	g_object_class_install_property (gobject_class,
+					 PROP_FILENAME,
+					 g_param_spec_string ("filename",
+							      "Filename",
+							      "The archive filename",
+							      NULL,
+							      G_PARAM_READWRITE));
+	g_object_class_install_property (gobject_class,
+					 PROP_MIME_TYPE,
+					 g_param_spec_string ("mime-type",
+							      "Mime type",
+							      "The file mime-type",
+							      NULL,
+							      G_PARAM_READWRITE));	
 }
 
 
 static void
 fr_command_init (FrCommand *comm)
 {
+	comm->files = g_ptr_array_sized_new (INITIAL_SIZE);
+	
 	comm->filename = NULL;
 	comm->e_filename = NULL;
-	comm->file_list = NULL;
 	comm->fake_load = FALSE;
 
 	comm->propCanModify = TRUE;
@@ -243,62 +411,9 @@ fr_command_init (FrCommand *comm)
 	comm->propExtractCanJunkPaths = FALSE;
 	comm->propPassword = FALSE;
 	comm->propTest = FALSE;
-	comm->propCanExtractAll = TRUE;
-}
-
-
-static void
-fr_command_start (FrProcess *process,
-		  gpointer   data)
-{
-	FrCommand *comm = FR_COMMAND (data);
-	
-	g_signal_emit (G_OBJECT (comm),
-		       fr_command_signals[START], 
-		       0,
-		       comm->action);
-}
-
-
-static void
-fr_command_done (FrProcess   *process,
-		 FRProcError *error, 
-		 gpointer     data)
-{
-	FrCommand *comm = FR_COMMAND (data);
-
-	comm->process->restart = FALSE;
-	if (error->type != FR_PROC_ERROR_NONE)
-		fr_command_handle_error (comm, error);
-
-	if (comm->process->restart)
-		fr_process_start (comm->process);
-	else
-		g_signal_emit (G_OBJECT (comm),
-			       fr_command_signals[DONE], 
-			       0,
-			       comm->action, 
-			       error);
-}
-
-
-void
-fr_command_construct (FrCommand  *comm,
-		      FrProcess  *process,
-		      const char *fr_command_name)
-{
-	fr_command_set_filename (comm, fr_command_name);
-
-	g_object_ref (G_OBJECT (process));
-	comm->process = process;
-	g_signal_connect (G_OBJECT (comm->process),
-			  "start",
-			  G_CALLBACK (fr_command_start),
-			  comm);
-	g_signal_connect (G_OBJECT (comm->process),
-			  "done",
-			  G_CALLBACK (fr_command_done),
-			  comm);
+	comm->propCanExtractAll = TRUE; 	
+	comm->propCanDeleteNonEmptyFolders = TRUE;
+	comm->propCanExtractNonEmptyFolders = TRUE;
 }
 
 
@@ -314,24 +429,11 @@ fr_command_finalize (GObject *object)
 
 	if (comm->filename != NULL)
 		g_free (comm->filename);
-
 	if (comm->e_filename != NULL)
 		g_free (comm->e_filename);
-
-	if (comm->file_list != NULL) {
-		g_list_foreach (comm->file_list,
-				(GFunc) file_data_free,
-				NULL);
-		g_list_free (comm->file_list);
-	}
-
-	g_signal_handlers_disconnect_matched (G_OBJECT (comm->process),
-					      G_SIGNAL_MATCH_DATA, 
-					      0, 
-					      0, NULL, 
-					      0,
-					      comm);
-	g_object_unref (G_OBJECT (comm->process));
+	if (comm->files != NULL) 
+		g_ptr_array_free_full (comm->files, (GFunc) file_data_free, NULL);
+	fr_command_set_process (comm, NULL);
 
 	/* Chain up */
 	if (G_OBJECT_CLASS (parent_class)->finalize)
@@ -345,21 +447,30 @@ fr_command_set_filename (FrCommand  *comm,
 {
 	g_return_if_fail (FR_IS_COMMAND (comm));
 
-	if (comm->filename != NULL)
+	if (comm->filename != NULL) {
 		g_free (comm->filename);
+		comm->filename = NULL;
+	}
 
-	if (comm->e_filename != NULL)
+	if (comm->e_filename != NULL) {
 		g_free (comm->e_filename);
+		comm->e_filename = NULL;
+	}
+	
+	if (filename == NULL)
+		return;
 
 	if (! g_path_is_absolute (filename)) {
 		char *current_dir;
+
 		current_dir = g_get_current_dir ();
 		comm->filename = g_strconcat (current_dir,
 					      "/", 
 					      filename, 
 					      NULL);
 		g_free (current_dir);
-	} else
+	} 
+	else
 		comm->filename = g_strdup (filename);
 
 	comm->e_filename = shell_escape (comm->filename);
@@ -377,10 +488,9 @@ fr_command_list (FrCommand  *comm,
 
 	fr_command_progress (comm, -1.0);
 
-	if (comm->file_list != NULL) {
-		g_list_foreach (comm->file_list, (GFunc) file_data_free, NULL);
-		g_list_free (comm->file_list);
-		comm->file_list = NULL;
+	if (comm->files != NULL) {
+		g_ptr_array_free_full (comm->files, (GFunc) file_data_free, NULL);
+		comm->files = g_ptr_array_sized_new (INITIAL_SIZE);
 	}
 
 	comm->action = FR_ACTION_LISTING_CONTENT;
@@ -398,7 +508,7 @@ fr_command_add (FrCommand     *comm,
 		const char    *base_dir,
 		gboolean       update,
 		const char    *password,
-		FRCompression  compression)
+		FrCompression  compression)
 {
 	fr_command_progress (comm, -1.0);
 
@@ -478,7 +588,7 @@ fr_command_uncompress (FrCommand *comm)
 
 void
 fr_command_recompress (FrCommand     *comm,
-		       FRCompression  compression)
+		       FrCompression  compression)
 {
 	fr_command_progress (comm, -1.0);	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->recompress (comm, compression);
@@ -486,13 +596,21 @@ fr_command_recompress (FrCommand     *comm,
 
 
 char *
-fr_command_escape (FrCommand     *comm,
-		   const char    *str)
+fr_command_escape (FrCommand  *comm,
+		   const char *str)
 {
 	return FR_COMMAND_GET_CLASS (G_OBJECT (comm))->escape (comm, str);
 }
 
 
+gboolean
+fr_command_is_capable_of (FrCommand     *comm, 
+			  FrCommandCaps  requested_capabilities)
+{
+	return (((comm->capabilities ^ requested_capabilities) & requested_capabilities) == 0);
+}
+
+
 /* fraction == -1 means : I don't known how much time the current operation
  *                        will take, the dialog will display this info pulsing 
  *                        the progress bar. 
@@ -500,8 +618,8 @@ fr_command_escape (FrCommand     *comm,
  *                        accomplished. 
  */
 void
-fr_command_progress (FrCommand     *comm,
-		     double         fraction)
+fr_command_progress (FrCommand *comm,
+		     double     fraction)
 {
 	g_signal_emit (G_OBJECT (comm),
 		       fr_command_signals[PROGRESS], 
@@ -511,8 +629,8 @@ fr_command_progress (FrCommand     *comm,
 
 
 void
-fr_command_message (FrCommand     *comm,
-		    const char    *msg)
+fr_command_message (FrCommand  *comm,
+		    const char *msg)
 {
 	g_signal_emit (G_OBJECT (comm),
 		       fr_command_signals[MESSAGE], 
@@ -522,17 +640,34 @@ fr_command_message (FrCommand     *comm,
 
 
 void
-fr_command_set_n_files (FrCommand     *comm,
-			int            n_files)
+fr_command_set_n_files (FrCommand *comm,
+			int        n_files)
 {
 	comm->n_files = n_files;
 	comm->n_file = 0;
 }
 
 
+void
+fr_command_add_file (FrCommand *comm,
+		     FileData  *fdata)
+{
+	file_data_update_content_type (fdata);
+	g_ptr_array_add (comm->files, fdata);
+}
+
+
+void
+fr_command_set_mime_type (FrCommand  *comm,
+			  const char *mime_type)
+{
+	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->set_mime_type (comm, mime_type);
+}
+
+
 void
 fr_command_handle_error (FrCommand *comm,
-			 FRProcError *error)
+			 FrProcError *error)
 {
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->handle_error (comm, error);
 }
