@@ -46,17 +46,17 @@ enum {
 static GObjectClass *parent_class;
 static guint fr_process_signals[LAST_SIGNAL] = { 0 };
 
-static void fr_process_class_init (FRProcessClass *class);
-static void fr_process_init       (FRProcess      *fr_proc);
+static void fr_process_class_init (FrProcessClass *class);
+static void fr_process_init       (FrProcess      *fr_proc);
 static void fr_process_finalize   (GObject        *object);
 
 
-static FRCommandInfo *
-fr_command_info_new ()
+static FrCommandInfo *
+fr_command_info_new (void)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
-	c_info = g_new0 (FRCommandInfo, 1);
+	c_info = g_new0 (FrCommandInfo, 1);
 	c_info->args = NULL;
 	c_info->dir = NULL;
 	c_info->sticky = FALSE;
@@ -67,7 +67,7 @@ fr_command_info_new ()
 
 
 static void
-fr_command_info_free (FRCommandInfo * c_info)
+fr_command_info_free (FrCommandInfo * c_info)
 {
 	if (c_info == NULL)
 		return;
@@ -90,43 +90,43 @@ fr_command_info_free (FRCommandInfo * c_info)
 GType
 fr_process_get_type (void)
 {
-        static GType type = 0;
+	static GType type = 0;
 
-        if (! type) {
-                GTypeInfo type_info = {
-			sizeof (FRProcessClass),
+	if (! type) {
+		GTypeInfo type_info = {
+			sizeof (FrProcessClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_process_class_init,
 			NULL,
 			NULL,
-			sizeof (FRProcess),
+			sizeof (FrProcess),
 			0,
 			(GInstanceInitFunc) fr_process_init
-                };
+		};
 
 		type = g_type_register_static (G_TYPE_OBJECT,
 					       "FRProcess",
 					       &type_info,
 					       0);
-        }
+	}
 
-        return type;
+	return type;
 }
 
 
 static void
-fr_process_class_init (FRProcessClass *class)
+fr_process_class_init (FrProcessClass *class)
 {
-        GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
 
-        parent_class = g_type_class_peek_parent (class);
+	parent_class = g_type_class_peek_parent (class);
 
 	fr_process_signals[START] =
 		g_signal_new ("start",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (FRProcessClass, start),
+			      G_STRUCT_OFFSET (FrProcessClass, start),
 			      NULL, NULL,
 			      fr_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
@@ -134,29 +134,28 @@ fr_process_class_init (FRProcessClass *class)
 		g_signal_new ("done",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (FRProcessClass, done),
+			      G_STRUCT_OFFSET (FrProcessClass, done),
 			      NULL, NULL,
-			      fr_marshal_VOID__POINTER,
-			      G_TYPE_NONE, 1,
-			      G_TYPE_POINTER);
+			      fr_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 	fr_process_signals[STICKY_ONLY] =
 		g_signal_new ("sticky_only",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (FRProcessClass, sticky_only),
+			      G_STRUCT_OFFSET (FrProcessClass, sticky_only),
 			      NULL, NULL,
 			      fr_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
 
 	gobject_class->finalize = fr_process_finalize;
 
-        class->start = NULL;
-        class->done  = NULL;
+	class->start = NULL;
+	class->done  = NULL;
 }
 
 
 static void
-fr_process_init (FRProcess *fr_proc)
+fr_process_init (FrProcess *fr_proc)
 {
 	fr_proc->term_on_stop = TRUE;
 
@@ -194,23 +193,23 @@ fr_process_init (FRProcess *fr_proc)
 }
 
 
-FRProcess * 
+FrProcess *
 fr_process_new ()
 {
 	return FR_PROCESS (g_object_new (FR_TYPE_PROCESS, NULL));
 }
 
 
-static void _fr_process_stop (FRProcess *fr_proc, gboolean emit_signal);
+static void _fr_process_stop (FrProcess *fr_proc, gboolean emit_signal);
 
 
 static void
 fr_process_finalize (GObject *object)
 {
-	FRProcess *fr_proc;
+	FrProcess *fr_proc;
 
 	g_return_if_fail (object != NULL);
-        g_return_if_fail (FR_IS_PROCESS (object));
+	g_return_if_fail (FR_IS_PROCESS (object));
 
 	fr_proc = FR_PROCESS (object);
 
@@ -238,33 +237,35 @@ fr_process_finalize (GObject *object)
 
 	/* Chain up */
 
-        if (G_OBJECT_CLASS (parent_class)->finalize)
+	if (G_OBJECT_CLASS (parent_class)->finalize)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 
 void
-fr_process_begin_command (FRProcess  *fr_proc, 
+fr_process_begin_command (FrProcess  *fr_proc,
 			  const char *arg)
 {
-	FRCommandInfo * c_info;
+	FrCommandInfo * c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
 	c_info = fr_command_info_new ();
 	c_info->args = g_list_prepend (NULL, g_strdup (arg));
+	
 	g_ptr_array_add (fr_proc->comm, c_info);
+	
 	fr_proc->n_comm++;
 	fr_proc->current_comm = fr_proc->n_comm;
 }
 
 
 void
-fr_process_begin_command_at (FRProcess  *fr_proc, 
+fr_process_begin_command_at (FrProcess  *fr_proc,
 			     const char *arg,
 			     int         index)
 {
-	FRCommandInfo *c_info, *old_c_info;
+	FrCommandInfo *c_info, *old_c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 	g_return_if_fail (index >= 0 && index <= fr_proc->n_comm);
@@ -278,15 +279,16 @@ fr_process_begin_command_at (FRProcess  *fr_proc,
 
 	c_info = fr_command_info_new ();
 	c_info->args = g_list_prepend (NULL, g_strdup (arg));
+	
 	g_ptr_array_index (fr_proc->comm, index) = c_info;
 }
 
 
 void
-fr_process_set_working_dir (FRProcess  *fr_proc, 
+fr_process_set_working_dir (FrProcess  *fr_proc,
 			    const char *dir)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
@@ -298,10 +300,10 @@ fr_process_set_working_dir (FRProcess  *fr_proc,
 
 
 void
-fr_process_set_sticky (FRProcess *fr_proc, 
+fr_process_set_sticky (FrProcess *fr_proc,
 		       gboolean   sticky)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
@@ -311,10 +313,10 @@ fr_process_set_sticky (FRProcess *fr_proc,
 
 
 void
-fr_process_set_ignore_error (FRProcess *fr_proc, 
+fr_process_set_ignore_error (FrProcess *fr_proc,
 			     gboolean   ignore_error)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
@@ -324,10 +326,10 @@ fr_process_set_ignore_error (FRProcess *fr_proc,
 
 
 void
-fr_process_add_arg (FRProcess  *fr_proc, 
+fr_process_add_arg (FrProcess  *fr_proc,
 		    const char *arg)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
@@ -337,12 +339,12 @@ fr_process_add_arg (FRProcess  *fr_proc,
 
 
 void
-fr_process_set_arg_at (FRProcess  *fr_proc, 
+fr_process_set_arg_at (FrProcess  *fr_proc,
 		       int         n_comm,
 		       int         n_arg,
 		       const char *arg_value)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 	GList         *arg;
 
 	g_return_if_fail (fr_proc != NULL);
@@ -350,18 +352,18 @@ fr_process_set_arg_at (FRProcess  *fr_proc,
 	c_info = g_ptr_array_index (fr_proc->comm, n_comm);
 	arg = g_list_nth (c_info->args, n_arg);
 	g_return_if_fail (arg != NULL);
-	
+
 	g_free (arg->data);
 	arg->data = g_strdup (arg_value);
 }
 
 
 void
-fr_process_set_begin_func (FRProcess    *fr_proc, 
+fr_process_set_begin_func (FrProcess    *fr_proc,
 			   ProcFunc      func,
 			   gpointer      func_data)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
@@ -372,11 +374,11 @@ fr_process_set_begin_func (FRProcess    *fr_proc,
 
 
 void
-fr_process_set_end_func (FRProcess    *fr_proc, 
+fr_process_set_end_func (FrProcess    *fr_proc,
 			 ProcFunc      func,
 			 gpointer      func_data)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
@@ -387,14 +389,17 @@ fr_process_set_end_func (FRProcess    *fr_proc,
 
 
 void
-fr_process_set_continue_func (FRProcess    *fr_proc, 
+fr_process_set_continue_func (FrProcess    *fr_proc,
 			      ContinueFunc  func,
 			      gpointer      func_data)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
+	if (fr_proc->current_comm < 0)
+		return;
+
 	c_info = g_ptr_array_index (fr_proc->comm, fr_proc->current_comm);
 	c_info->continue_func = func;
 	c_info->continue_data = func_data;
@@ -402,9 +407,9 @@ fr_process_set_continue_func (FRProcess    *fr_proc,
 
 
 void
-fr_process_end_command (FRProcess *fr_proc)
+fr_process_end_command (FrProcess *fr_proc)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 
 	g_return_if_fail (fr_proc != NULL);
 
@@ -414,21 +419,21 @@ fr_process_end_command (FRProcess *fr_proc)
 
 
 void
-fr_process_clear (FRProcess *fr_proc)
+fr_process_clear (FrProcess *fr_proc)
 {
 	gint i;
 
 	g_return_if_fail (fr_proc != NULL);
 
 	for (i = 0; i <= fr_proc->n_comm; i++) {
-		FRCommandInfo *c_info;
+		FrCommandInfo *c_info;
 
 		c_info = g_ptr_array_index (fr_proc->comm, i);
 		fr_command_info_free (c_info);
 		g_ptr_array_index (fr_proc->comm, i) = NULL;
 	}
 
-	for (i = 0; i <= fr_proc->n_comm; i++) 
+	for (i = 0; i <= fr_proc->n_comm; i++)
 		g_ptr_array_remove_index_fast (fr_proc->comm, 0);
 
 	fr_proc->n_comm = -1;
@@ -437,7 +442,7 @@ fr_process_clear (FRProcess *fr_proc)
 
 
 void
-fr_process_set_out_line_func (FRProcess    *fr_proc, 
+fr_process_set_out_line_func (FrProcess    *fr_proc,
 			      ProcLineFunc  func,
 			      gpointer      data)
 {
@@ -448,7 +453,7 @@ fr_process_set_out_line_func (FRProcess    *fr_proc,
 
 
 void
-fr_process_set_err_line_func (FRProcess    *fr_proc, 
+fr_process_set_err_line_func (FrProcess    *fr_proc,
 			      ProcLineFunc  func,
 			      gpointer      data)
 {
@@ -459,14 +464,14 @@ fr_process_set_err_line_func (FRProcess    *fr_proc,
 
 
 static gboolean
-process_output (FRProcess *fr_proc)
+process_output (FrProcess *fr_proc)
 {
 	int   n, i;
 	char *line, *eol;
 
  again:
-	n = read (fr_proc->output_fd, 
-		  fr_proc->o_buffer + fr_proc->o_not_processed, 
+	n = read (fr_proc->output_fd,
+		  fr_proc->o_buffer + fr_proc->o_not_processed,
 		  BUFFER_SIZE - fr_proc->o_not_processed);
 
 	if ((n < 0) && (errno == EINTR))
@@ -480,15 +485,15 @@ process_output (FRProcess *fr_proc)
 	line = fr_proc->o_buffer;
 	while (*line != 0) {
 		eol = strchr (line, '\n');
-		
+
 		if (eol != NULL)
 			*(eol++) = 0;
 		else if (n == 0) /* EOF on file descriptor */
 			eol = line + strlen (line);
-		else 
+		else
 			break;
 
-		fr_proc->raw_output = g_list_prepend (fr_proc->raw_output, 
+		fr_proc->raw_output = g_list_prepend (fr_proc->raw_output,
 						      g_strdup (line));
 
 		if (fr_proc->o_proc_line_func != NULL) {
@@ -498,7 +503,7 @@ process_output (FRProcess *fr_proc)
 
 		line = eol;
 	}
-	
+
 	/* shift unprocessed text to the beginning. */
 
 	fr_proc->o_not_processed = strlen (line);
@@ -510,14 +515,14 @@ process_output (FRProcess *fr_proc)
 
 
 static gboolean
-process_error (FRProcess *fr_proc)
+process_error (FrProcess *fr_proc)
 {
 	int   n, i;
 	char *line, *eol;
 
  again:
-	n = read (fr_proc->error_fd, 
-		  fr_proc->e_buffer + fr_proc->e_not_processed, 
+	n = read (fr_proc->error_fd,
+		  fr_proc->e_buffer + fr_proc->e_not_processed,
 		  BUFFER_SIZE - fr_proc->e_not_processed);
 
 	if ((n < 0) && (errno == EINTR))
@@ -531,15 +536,15 @@ process_error (FRProcess *fr_proc)
 	line = fr_proc->e_buffer;
 	while (*line != 0) {
 		eol = strchr (line, '\n');
-		
+
 		if (eol != NULL)
 			*(eol++) = 0;
 		else if (n == 0) /* EOF on file descriptor */
 			eol = line + strlen (line);
-		else 
+		else
 			break;
 
-		fr_proc->raw_error = g_list_prepend (fr_proc->raw_error, 
+		fr_proc->raw_error = g_list_prepend (fr_proc->raw_error,
 						     g_strdup (line));
 
 		if (fr_proc->e_proc_line_func != NULL) {
@@ -549,7 +554,7 @@ process_error (FRProcess *fr_proc)
 
 		line = eol;
 	}
-	
+
 	/* shift unprocessed text to the beginning. */
 
 	fr_proc->e_not_processed = strlen (line);
@@ -565,7 +570,7 @@ static gboolean check_child (gpointer data);
 
 static void child_setup (gpointer user_data)
 {
-	FRProcess *fr_proc = user_data;
+	FrProcess *fr_proc = user_data;
 
 	if (fr_proc->use_standard_locale)
 		putenv ("LC_ALL=C");
@@ -573,9 +578,9 @@ static void child_setup (gpointer user_data)
 
 
 static void
-start_current_command (FRProcess *fr_proc)
+start_current_command (FrProcess *fr_proc)
 {
-	FRCommandInfo  *c_info;
+	FrCommandInfo  *c_info;
 	GList          *arg_list, *scan;
 	GString        *command;
 	char           *dir;
@@ -583,39 +588,40 @@ start_current_command (FRProcess *fr_proc)
 	int             i = 0;
 
 	debug (DEBUG_INFO, "%d/%d) ", fr_proc->current_command, fr_proc->n_comm);
+
+	c_info = g_ptr_array_index (fr_proc->comm, fr_proc->current_command);
 	
-	c_info = g_ptr_array_index (fr_proc->comm, 
-				    fr_proc->current_command);
 	arg_list = c_info->args;
 	dir = c_info->dir;
 
-	if (dir != NULL) 
-		debug (DEBUG_INFO, "cd %s\n", dir); 
-	
+	if (dir != NULL)
+		debug (DEBUG_INFO, "cd %s\n", dir);
+
 	command = NULL;
-	
+
 	argv = g_new (char *, 4);
 	argv[i++] = "/bin/sh";
 	argv[i++] = "-c";
 
 	command = g_string_new ("");
 	for (scan = arg_list; scan; scan = scan->next) {
-		g_string_append (command, scan->data);
+		if (scan->data != NULL)
+			g_string_append (command, scan->data);
 		if (scan->next != NULL)
 			g_string_append_c (command, ' ');
 	}
-	
+
 	argv[i++] = command->str;
 	argv[i] = NULL;
 
 #ifdef DEBUG
 	{
 		int j;
-		
+
 		g_print ("/bin/sh ");
 		for (j = 0; j < i; j++)
 			g_print ("%s ", argv[j]);
-		g_print ("\n"); 
+		g_print ("\n");
 	}
 #endif
 
@@ -626,7 +632,7 @@ start_current_command (FRProcess *fr_proc)
 					argv,
 					NULL,
 					(G_SPAWN_LEAVE_DESCRIPTORS_OPEN
-					 | G_SPAWN_SEARCH_PATH 
+					 | G_SPAWN_SEARCH_PATH
 					 | G_SPAWN_DO_NOT_REAP_CHILD),
 					child_setup,
 					fr_proc,
@@ -634,12 +640,12 @@ start_current_command (FRProcess *fr_proc)
 					NULL,
 					&fr_proc->output_fd,
 					&fr_proc->error_fd,
-					&fr_proc->error.gerror)) {
+					&fr_proc->error.gerror)) 
+	{
 		fr_proc->error.type = FR_PROC_ERROR_SPAWN;
-		g_signal_emit (G_OBJECT (fr_proc), 
+		g_signal_emit (G_OBJECT (fr_proc),
 			       fr_process_signals[DONE],
-			       0,
-			       &fr_proc->error);
+			       0);
 
 		g_free (argv);
 		g_string_free (command, TRUE);
@@ -655,25 +661,25 @@ start_current_command (FRProcess *fr_proc)
 
 	fr_proc->o_not_processed = 0;
 	fr_proc->e_not_processed = 0;
-	fr_proc->log_timeout = g_timeout_add (REFRESH_RATE, 
+	fr_proc->log_timeout = g_timeout_add (REFRESH_RATE,
 					      check_child,
 					      fr_proc);
 }
 
 
 static gboolean
-command_is_sticky (FRProcess *fr_proc, 
+command_is_sticky (FrProcess *fr_proc,
 		   int        i)
 {
-	FRCommandInfo *c_info;
+	FrCommandInfo *c_info;
 	c_info = g_ptr_array_index (fr_proc->comm, i);
 	return c_info->sticky;
 }
 
 
 static void
-allow_sticky_processes_only (FRProcess *fr_proc,
-			     gboolean   emit_signal) 
+allow_sticky_processes_only (FrProcess *fr_proc,
+			     gboolean   emit_signal)
 {
 	if (! fr_proc->sticky_only) {
 		/* Remember the first error. */
@@ -684,10 +690,10 @@ allow_sticky_processes_only (FRProcess *fr_proc,
 		if (fr_proc->error.gerror != NULL)
 			fr_proc->first_error.gerror = g_error_copy (fr_proc->error.gerror);
 	}
-	
+
 	fr_proc->sticky_only = TRUE;
-	if (emit_signal)
-		g_signal_emit (G_OBJECT (fr_proc), 
+	if (emit_signal) 
+		g_signal_emit (G_OBJECT (fr_proc),
 			       fr_process_signals[STICKY_ONLY],
 			       0);
 }
@@ -696,8 +702,8 @@ allow_sticky_processes_only (FRProcess *fr_proc,
 static gint
 check_child (gpointer data)
 {
-	FRProcess      *fr_proc = data;
-	FRCommandInfo  *c_info;
+	FrProcess      *fr_proc = data;
+	FrCommandInfo  *c_info;
 	pid_t           pid;
 	int             status;
 	gboolean        continue_process;
@@ -706,7 +712,7 @@ check_child (gpointer data)
 
 	/* Remove check. */
 
-	g_source_remove (fr_proc->log_timeout);	
+	g_source_remove (fr_proc->log_timeout);
 	fr_proc->log_timeout = 0;
 
 	process_output (fr_proc);
@@ -715,7 +721,7 @@ check_child (gpointer data)
 	pid = waitpid (fr_proc->command_pid, &status, WNOHANG);
 	if (pid != fr_proc->command_pid) {
 		/* Add check again. */
-		fr_proc->log_timeout = g_timeout_add (REFRESH_RATE, 
+		fr_proc->log_timeout = g_timeout_add (REFRESH_RATE,
 						      check_child,
 						      fr_proc);
 		return FALSE;
@@ -725,18 +731,18 @@ check_child (gpointer data)
 		fr_proc->error.type = FR_PROC_ERROR_NONE;
 		debug (DEBUG_INFO, "[ignore error]\n");
 	}
-
-	if (fr_proc->error.type != FR_PROC_ERROR_STOPPED) {
+	else if (fr_proc->error.type != FR_PROC_ERROR_STOPPED) {
 		if (WIFEXITED (status)) {
 			if (WEXITSTATUS (status) == 0)
 				fr_proc->error.type = FR_PROC_ERROR_NONE;
-			else if (WEXITSTATUS (status) == 255) 
+			else if (WEXITSTATUS (status) == 255)
 				fr_proc->error.type = FR_PROC_ERROR_COMMAND_NOT_FOUND;
 			else {
-				fr_proc->error.type = FR_PROC_ERROR_GENERIC;
+				fr_proc->error.type = FR_PROC_ERROR_COMMAND_ERROR;
 				fr_proc->error.status = WEXITSTATUS (status);
 			}
-		} else
+		}
+		else
 			fr_proc->error.type = FR_PROC_ERROR_EXITED_ABNORMALLY;
 	}
 
@@ -766,14 +772,14 @@ check_child (gpointer data)
 
 	/* Execute next command. */
 	if (continue_process) {
-		if (fr_proc->error.type != FR_PROC_ERROR_NONE) 
+		if (fr_proc->error.type != FR_PROC_ERROR_NONE)
 			allow_sticky_processes_only (fr_proc, TRUE);
-		
+
 		if (fr_proc->sticky_only) {
 			do {
 				fr_proc->current_command++;
 			} while ((fr_proc->current_command <= fr_proc->n_comm)
-				 && ! command_is_sticky (fr_proc, 
+				 && ! command_is_sticky (fr_proc,
 							 fr_proc->current_command));
 		} else
 			fr_proc->current_command++;
@@ -785,7 +791,7 @@ check_child (gpointer data)
 	}
 
 	/* Done */
-
+	
 	fr_proc->current_command = -1;
 
 	if (fr_proc->raw_output != NULL)
@@ -805,17 +811,16 @@ check_child (gpointer data)
 			fr_proc->error.gerror = g_error_copy (fr_proc->first_error.gerror);
 	}
 
-	g_signal_emit (G_OBJECT (fr_proc), 
+	g_signal_emit (G_OBJECT (fr_proc),
 		       fr_process_signals[DONE],
-		       0,
-		       &fr_proc->error);
+		       0);
 
 	return FALSE;
 }
 
 
 void
-fr_process_use_standard_locale (FRProcess *fr_proc,
+fr_process_use_standard_locale (FrProcess *fr_proc,
 				gboolean   use_stand_locale)
 {
 	g_return_if_fail (fr_proc != NULL);
@@ -824,7 +829,7 @@ fr_process_use_standard_locale (FRProcess *fr_proc,
 
 
 void
-fr_process_start (FRProcess *fr_proc)
+fr_process_start (FrProcess *fr_proc)
 {
 	g_return_if_fail (fr_proc != NULL);
 
@@ -843,25 +848,24 @@ fr_process_start (FRProcess *fr_proc)
 		fr_proc->raw_error = NULL;
 	}
 
-	if (!fr_proc->restart)
-		g_signal_emit (G_OBJECT (fr_proc), 
-			       fr_process_signals[START],
-			       0);
-
 	fr_proc->sticky_only = FALSE;
 	fr_proc->current_command = 0;
 	fr_proc->error.type = FR_PROC_ERROR_NONE;
 
+	if (!fr_proc->restart)
+		g_signal_emit (G_OBJECT (fr_proc),
+			       fr_process_signals[START],
+			       0);
+
 	fr_proc->stopping = FALSE;
 
 	if (fr_proc->n_comm == -1) {
 		fr_proc->running = FALSE;
-		g_signal_emit (G_OBJECT (fr_proc), 
+		g_signal_emit (G_OBJECT (fr_proc),
 			       fr_process_signals[DONE],
-			       0,
-			       &fr_proc->error);
-
-	} else {
+			       0);
+	} 
+	else {
 		fr_proc->running = TRUE;
 		start_current_command (fr_proc);
 	}
@@ -869,7 +873,7 @@ fr_process_start (FRProcess *fr_proc)
 
 
 static void
-_fr_process_stop (FRProcess *fr_proc,
+_fr_process_stop (FrProcess *fr_proc,
 		  gboolean   emit_signal)
 {
 	g_return_if_fail (fr_proc != NULL);
@@ -883,10 +887,10 @@ _fr_process_stop (FRProcess *fr_proc,
 	fr_proc->stopping = TRUE;
 	fr_proc->error.type = FR_PROC_ERROR_STOPPED;
 
-	if (command_is_sticky (fr_proc, fr_proc->current_command)) 
+	if (command_is_sticky (fr_proc, fr_proc->current_command))
 		allow_sticky_processes_only (fr_proc, emit_signal);
 
-	else if (fr_proc->term_on_stop) 
+	else if (fr_proc->term_on_stop)
 		kill (fr_proc->command_pid, SIGTERM);
 
 	else {
@@ -894,7 +898,7 @@ _fr_process_stop (FRProcess *fr_proc,
 			g_source_remove (fr_proc->log_timeout);
 			fr_proc->log_timeout = 0;
 		}
-		
+
 		fr_proc->command_pid = 0;
 
 		close (fr_proc->output_fd);
@@ -902,20 +906,19 @@ _fr_process_stop (FRProcess *fr_proc,
 
 		fr_proc->output_fd = 0;
 		fr_proc->error_fd = 0;
-		
+
 		fr_proc->running = FALSE;
 
 		if (emit_signal)
-			g_signal_emit (G_OBJECT (fr_proc), 
+			g_signal_emit (G_OBJECT (fr_proc),
 				       fr_process_signals[DONE],
-				       0,
-				       &fr_proc->error);
+				       0);
 	}
 }
 
 
 void
-fr_process_stop (FRProcess *fr_proc)
+fr_process_stop (FrProcess *fr_proc)
 {
 	_fr_process_stop (fr_proc, TRUE);
 }
