@@ -23,11 +23,9 @@
 #ifndef FR_WINDOW_H
 #define FR_WINDOW_H
 
+#include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/libgnomeui.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include "typedefs.h"
-#include "file-list.h"
 #include "fr-archive.h"
 
 #define GCONF_NOTIFICATIONS 10
@@ -68,7 +66,7 @@ typedef enum {
 	FR_BATCH_ACTION_CLOSE,
 	FR_BATCH_ACTION_QUIT,
 	FR_BATCH_ACTIONS
-} FRBatchActionType;
+} FrBatchActionType;
 
 /* -- FrWindow -- */
 
@@ -85,15 +83,14 @@ typedef struct _FrWindowPrivateData FrWindowPrivateData;
 
 struct _FrWindow
 {
-	GnomeApp __parent;
-
-	FrArchive           *archive;
+	GtkWindow __parent;
+	FrArchive *archive;
 	FrWindowPrivateData *priv;
 };
 
 struct _FrWindowClass
 {
-	GnomeAppClass __parent_class;
+	GtkWindowClass __parent_class;
 
 	/*<signals>*/
 
@@ -103,7 +100,7 @@ struct _FrWindowClass
 
 GType       fr_window_get_type                  (void);
 GtkWidget * fr_window_new                       (void);
-void        fr_window_close                     (FrWindow *window);
+void        fr_window_close                     (FrWindow      *window);
 
 /* archive operations */
 
@@ -117,7 +114,8 @@ const char *fr_window_get_archive_uri           (FrWindow      *window);
 const char *fr_window_get_paste_archive_uri     (FrWindow      *window);
 gboolean    fr_window_archive_is_present        (FrWindow      *window);
 void        fr_window_archive_save_as           (FrWindow      *window,
-						 const char    *filename);
+						 const char    *filename,
+						 const char    *password);
 void        fr_window_archive_reload            (FrWindow      *window);
 void        fr_window_archive_rename            (FrWindow      *window,
 						 const char    *filename);
@@ -127,6 +125,7 @@ void        fr_window_archive_add_files         (FrWindow      *window,
 void        fr_window_archive_add_with_wildcard (FrWindow      *window,
 						 const char    *include_files,
 						 const char    *exclude_files,
+						 const char    *exclude_folders,
 						 const char    *base_dir,
 						 const char    *dest_dir,
 						 gboolean       update,
@@ -138,20 +137,20 @@ void        fr_window_archive_add_directory     (FrWindow      *window,
 						 const char    *dest_dir,
 						 gboolean       update,
 						 const char    *password,
-						 FRCompression  compression);
+						 FrCompression  compression);
 void        fr_window_archive_add_items         (FrWindow      *window,
 						 GList         *dir_list,
 						 const char    *base_dir,
 						 const char    *dest_dir,
 						 gboolean       update,
 						 const char    *password,
-						 FRCompression  compression);
+						 FrCompression  compression);
 void        fr_window_archive_add_dropped_items (FrWindow      *window,
 						 GList         *item_list,
 						 gboolean       update);
 void        fr_window_archive_remove            (FrWindow      *window,
 						 GList         *file_list,
-						 FRCompression  compression);
+						 FrCompression  compression);
 void        fr_window_archive_extract           (FrWindow      *window,
 						 GList         *file_list,
 						 const char    *extract_to_dir,
@@ -171,7 +170,7 @@ void        fr_window_set_password              (FrWindow      *window,
 void        fr_window_set_password_for_paste    (FrWindow      *window,
 					         const char    *password);						 
 const char *fr_window_get_password              (FrWindow      *window);
-FRCompression fr_window_get_compression 	(FrWindow      *window);
+FrCompression fr_window_get_compression 	(FrWindow      *window);
 void        fr_window_view_folder_after_extract (FrWindow      *window,
 					 	 gboolean       view);
 
@@ -187,7 +186,7 @@ void       fr_window_go_forward                 (FrWindow       *window);
 void       fr_window_current_folder_activated   (FrWindow       *window,
 						 gboolean        from_sidebar);
 void       fr_window_set_list_mode              (FrWindow       *window,
-						 FRWindowListMode  list_mode);
+						 FrWindowListMode  list_mode);
 
 /**/
 
@@ -207,8 +206,9 @@ GList *    fr_window_get_folder_tree_selection    (FrWindow    *window,
 GList *    fr_window_get_selection                (FrWindow    *window,
 		  	 			   gboolean     from_sidebar,
 		  	 			   char       **return_base_dir);				     		   
-GtkListStore *
+GtkTreeModel *
 	   fr_window_get_list_store               (FrWindow    *window);
+void       fr_window_find                         (FrWindow    *window);	   
 void       fr_window_select_all                   (FrWindow    *window);
 void       fr_window_unselect_all                 (FrWindow    *window);
 void       fr_window_set_sort_type                (FrWindow    *window,
@@ -244,7 +244,9 @@ void        fr_window_open_files_with_command     (FrWindow   *window,
 						   char       *command);
 void        fr_window_open_files_with_application (FrWindow   *window,
 						   GList      *file_list,
-						   GnomeVFSMimeApplication *app);
+						   GAppInfo   *app);
+gboolean    fr_window_update_files                (FrWindow   *window,
+						   GList      *file_list);			   
 void        fr_window_update_columns_visibility   (FrWindow   *window);
 void        fr_window_update_history_list         (FrWindow   *window);
 void        fr_window_set_default_dir             (FrWindow   *window,
@@ -274,13 +276,13 @@ void        fr_window_set_folders_visibility      (FrWindow   *window,
 
 void       fr_window_new_batch                    (FrWindow      *window);
 void       fr_window_set_current_batch_action     (FrWindow      *window,
-						   FRBatchActionType  action,
+						   FrBatchActionType  action,
 						   void          *data,
 						   GFreeFunc      free_func);
 void       fr_window_reset_current_batch_action   (FrWindow      *window);
 void       fr_window_restart_current_batch_action (FrWindow      *window);
 void       fr_window_append_batch_action          (FrWindow      *window,
-						   FRBatchActionType  action,
+						   FrBatchActionType  action,
 						   void          *data,
 						   GFreeFunc      free_func);
 void       fr_window_start_batch                  (FrWindow      *window);
@@ -291,8 +293,7 @@ void       fr_window_set_batch__extract           (FrWindow      *window,
 						   const char    *filename,
 						   const char    *dest_dir);
 void       fr_window_set_batch__extract_here      (FrWindow      *window,
-						   const char    *filename,
-						   const char    *dest_dir);
+						   const char    *filename);
 void       fr_window_set_batch__add               (FrWindow      *window,
 						   const char    *archive,
 						   GList         *file_list);
@@ -305,4 +306,6 @@ gboolean   fr_window_file_list_drag_data_get (FrWindow         *window,
 					      GtkSelectionData *selection_data,
 					      GList            *path_list);
 
+void       fr_window_update_dialog_closed    (FrWindow *window); 
+
 #endif /* FR_WINDOW_H */
