@@ -34,7 +34,7 @@ gboolean            strchrs                      (const char *str,
 char *              str_substitute               (const char *str,
 						  const char *from_str,
 						  const char *to_str);
-int                 strcmp_null_tollerant        (const char *s1, const char *s2);
+int                 strcmp_null_tolerant        (const char *s1, const char *s2);
 char*               escape_str_common            (const char *str,
 						  const char *meta_chars,
 						  const char  prefix,
@@ -43,20 +43,29 @@ char*               escape_str                   (const char  *str,
 						  const char  *meta_chars);
 char*               unescape_str                 (const char  *str);
 gchar *             shell_escape                 (const gchar *filename);
-gboolean            match_patterns               (char       **patterns,
+gboolean            match_regexps                (GRegex     **regexps,
 						  const char  *string,
-						  int          flags);
+						  GRegexMatchFlags match_options);
 char **             search_util_get_patterns     (const char  *pattern_string);
-char *              _g_strdup_with_max_size      (const char *s,
-						  int         max_size);
-const char *        eat_spaces                   (const char *line);
-const char *        eat_void_chars               (const char *line);
-char **             split_line                   (const char *line,
-						  int   n_fields);
-const char *        get_last_field               (const char *line,
-						  int         last_field);
-int                 n_fields                     (char      **str_array);
-char *              get_time_string              (time_t      time);
+GRegex **           search_util_get_regexps      (const char  *pattern_string,
+			                          GRegexCompileFlags  compile_options);
+void                free_regexps                 (GRegex     **regexps);
+char *              _g_strdup_with_max_size      (const char  *s,
+						  int          max_size);
+const char *        eat_spaces                   (const char  *line);
+const char *        eat_void_chars               (const char  *line);
+char **             split_line                   (const char  *line,
+						  int          n_fields);
+const char *        get_last_field               (const char  *line,
+						  int          last_field);
+int                 n_fields                     (char       **str_array);
+char *              get_time_string              (time_t       time);
+GPtrArray *         g_ptr_array_copy             (GPtrArray   *array);
+void                g_ptr_array_free_full        (GPtrArray   *array,
+                       				  GFunc        func,
+                       				  gpointer     user_data);
+void                g_ptr_array_reverse          (GPtrArray   *array);
+const char *        get_static_string            (const char  *s);
 
 /**/
 
