@@ -36,12 +36,15 @@
 #define PREF_LIST_SHOW_TIME        "/apps/file-roller/listing/show_time"
 #define PREF_LIST_SHOW_PATH        "/apps/file-roller/listing/show_path"
 #define PREF_LIST_USE_MIME_ICONS   "/apps/file-roller/listing/use_mime_icons"
+#define PREF_NAME_COLUMN_WIDTH     "/apps/file-roller/listing/name_column_width"
 
 #define PREF_UI_WINDOW_WIDTH       "/apps/file-roller/ui/window_width"
 #define PREF_UI_WINDOW_HEIGHT      "/apps/file-roller/ui/window_height"
+#define PREF_UI_SIDEBAR_WIDTH      "/apps/file-roller/ui/sidebar_width"
 #define PREF_UI_HISTORY_LEN        "/apps/file-roller/ui/history_len"
 #define PREF_UI_TOOLBAR            "/apps/file-roller/ui/view_toolbar"
 #define PREF_UI_STATUSBAR          "/apps/file-roller/ui/view_statusbar"
+#define PREF_UI_FOLDERS            "/apps/file-roller/ui/view_folders"
 
 #define PREF_EDIT_EDITORS          "/apps/file-roller/general/editors"
 #define PREF_ADD_COMPRESSION_LEVEL "/apps/file-roller/general/compression_level"
@@ -52,6 +55,15 @@
 #define PREF_EXTRACT_SKIP_NEWER       "/apps/file-roller/dialogs/extract/skip_newer"
 #define PREF_EXTRACT_RECREATE_FOLDERS "/apps/file-roller/dialogs/extract/recreate_folders"
 
+#define PREF_ADD_CURRENT_FOLDER       "/apps/file-roller/dialogs/add/current_folder"
+#define PREF_ADD_FILENAME             "/apps/file-roller/dialogs/add/filename"
+#define PREF_ADD_INCLUDE_FILES        "/apps/file-roller/dialogs/add/include_files"
+#define PREF_ADD_EXCLUDE_FILES        "/apps/file-roller/dialogs/add/exclude_files"
+#define PREF_ADD_EXCLUDE_FOLDERS      "/apps/file-roller/dialogs/add/exclude_folders"
+#define PREF_ADD_UPDATE               "/apps/file-roller/dialogs/add/update"
+#define PREF_ADD_RECURSIVE            "/apps/file-roller/dialogs/add/recursive"
+#define PREF_ADD_NO_SYMLINKS          "/apps/file-roller/dialogs/add/no_symlinks"
+
 #define PREF_BATCH_ADD_DEFAULT_EXTENSION "/apps/file-roller/dialogs/batch-add/default_extension"
 
 #define PREF_DESKTOP_ICON_THEME         "/desktop/gnome/file_views/icon_theme"
@@ -60,14 +72,14 @@
 #define PREF_DESKTOP_TOOLBAR_DETACHABLE "/desktop/gnome/interface/toolbar_detachable"
 #define PREF_NAUTILUS_CLICK_POLICY "/apps/nautilus/preferences/click_policy"
 
-FRWindowSortMethod  preferences_get_sort_method       (void);
-void                preferences_set_sort_method       (FRWindowSortMethod  i_value);
+FrWindowSortMethod  preferences_get_sort_method       (void);
+void                preferences_set_sort_method       (FrWindowSortMethod  i_value);
 GtkSortType         preferences_get_sort_type         (void);
 void                preferences_set_sort_type         (GtkSortType         i_value);
-FRWindowListMode    preferences_get_list_mode         (void);
-void                preferences_set_list_mode         (FRWindowListMode    i_value);
-FRCompression       preferences_get_compression_level (void);
-void                preferences_set_compression_level (FRCompression       i_value);
+FrWindowListMode    preferences_get_list_mode         (void);
+void                preferences_set_list_mode         (FrWindowListMode    i_value);
+FrCompression       preferences_get_compression_level (void);
+void                preferences_set_compression_level (FrCompression       i_value);
 void                pref_util_save_window_geometry    (GtkWindow          *window,
 						       const char         *dialog);
 void                pref_util_restore_window_geometry (GtkWindow          *window,
